#ifndef SALDOPUNTI_H
#define SALDOPUNTI_H

#include <QObject>
#include <QDate>

class SaldoPunti : public QObject
{
    Q_OBJECT
public:
    explicit SaldoPunti(QObject *parent = 0);

    int Punti;
    QDate Aggiornamento;
    int PuntiInScadenza;
    int AnnoPuntiInScadenza;
    QDate Scadenza;

    QString ToString();
    bool FromString(QString string);
signals:

public slots:

};

#endif // SALDOPUNTI_H
